@@ -146,11 +146,11 @@ def build_get_functions_str(node_name: str, exclusive_field_names: T.Set[str]) -
     )
     dict_fields_str = ", ".join([f'"{f}": {f}' for f in exclusive_field_names])
     get_str = f"""
-async def get(self, given_client: AsyncIOClient = None, {params_fields_str}) -> T.Optional[{node_name}]:
+async def get(self, *, given_client: AsyncIOClient = None, merge: bool = True, {params_fields_str}) -> T.Optional[{node_name}]:
     return await super().get(given_client=given_client, **{{{dict_fields_str}}})
     """
     gerror_str = f"""
-async def gerror(self, given_client: AsyncIOClient = None, {params_fields_str}) -> {node_name}:
+async def gerror(self, *, given_client: AsyncIOClient = None, merge: bool = True, {params_fields_str}) -> {node_name}:
     return await super().gerror(given_client=given_client, **{{{dict_fields_str}}})
     """
     return f"{get_str}\n{gerror_str}"
