@@ -551,6 +551,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         with safe_span(op=f"parse.{self._model_name}", description=f"{len(raw_d)=}"):
             if not only_one:
                 return [self.parse_nested_obj(d) for d in raw_d]
+            if not raw_d:
+                return None
             return self.parse_nested_obj(raw_d)
 
     def clear_top_level_filters_and_variables(self) -> None:
